@@ -34,7 +34,7 @@ from ..const import (  # COSE_KEY_LEN,
 from ..cose_key_interface import COSEKeyInterface
 from ..exceptions import EncodeError, VerifyError
 from ..utils import to_cis
-from .symmetric import AESCCMKey, AESGCMKey, ChaCha20Key
+from .symmetric import AESCCMKey, AESGCMKey, ChaCha20Key, HMACKey
 
 
 class OKPKey(COSEKeyInterface):
@@ -339,6 +339,8 @@ class OKPKey(COSEKeyInterface):
         }
         if cose_key[3] in [1, 2, 3]:
             return AESGCMKey(cose_key)
+        if cose_key[3] in [4, 5, 6, 7]:
+            return HMACKey(cose_key)
         if cose_key[3] in [10, 11, 12, 13, 30, 31, 32, 33]:
             return AESCCMKey(cose_key)
         # cose_key[3] == 24:
